var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from 'react';
import ReactDatePicker, { registerLocale } from 'react-datepicker';
import enGb from 'date-fns/locale/en-GB';
import { format, getSeconds, getHours, getMinutes, set } from 'date-fns';
import styled from 'styled-components';
import { Button, Icon } from "./..";
import { useOnClickOutside } from "../../utils";
import { PredefinedDates } from './PredefinedDates';
import { TimeControl } from './TimeControl';
import { getEndOfDay, getMaxDate, getStartOfDay, isSameDate, isValidDateRange, } from './utils';
import { TIME_FORMAT, DATE_FORMAT } from './consts';
import defaultTheme from "../../theme";
var DATEPICKER_BORDER_RADIUS = '1.25em';
var DatePickerComponent = function (_a) {
    var initialStartDate = _a.initialStartDate, initialEndDate = _a.initialEndDate, onChange = _a.onChange, noClear = _a.noClear, predefinedDates = _a.predefinedDates, fluid = _a.fluid, maxDaysRange = _a.maxDaysRange, modalPosition = _a.modalPosition;
    var _b = useState(false), open = _b[0], setOpen = _b[1];
    var _c = useState(null), startDate = _c[0], setStartDate = _c[1];
    var _d = useState(null), endDate = _d[0], setEndDate = _d[1];
    var _e = useState(null), prevEndDate = _e[0], setPrevEndDate = _e[1];
    var _f = useState(false), predefinedDate = _f[0], setPredefinedDate = _f[1];
    var _g = useState(true), timeValid = _g[0], setTimeValid = _g[1];
    var outRef = useOnClickOutside(function () { return handleCancel(); });
    var currentDate = new Date();
    var localeName = 'en-gb';
    var valid = isValidDateRange(startDate, endDate) && timeValid;
    useEffect(function () {
        registerLocale(localeName, enGb);
    }, []);
    useEffect(function () {
        init();
    }, [initialStartDate, initialEndDate]);
    var formatInitialDate = function (date) {
        return typeof date === 'number' ? new Date(date) : date;
    };
    var init = function () {
        setStartDate(formatInitialDate(initialStartDate));
        setEndDate(formatInitialDate(initialEndDate));
    };
    var handleDateChange = function (date) {
        var start = date[0], end = date[1];
        setStartDate(predefinedDate ? getStartOfDay(start) : start);
        setEndDate(end ? getEndOfDay(end) : null);
        // update time
        if (!predefinedDate && end && prevEndDate) {
            var hours = getHours(prevEndDate);
            var minutes = getMinutes(prevEndDate);
            var seconds = getSeconds(prevEndDate);
            var endDate_1 = set(end, {
                hours: hours,
                minutes: minutes,
                seconds: seconds,
            });
            setEndDate(endDate_1);
        }
        setPredefinedDate(false);
    };
    var handlePredefinedDateChange = function (_a) {
        var startDate = _a.startDate, endDate = _a.endDate;
        setStartDate(startDate);
        setEndDate(endDate);
        setPredefinedDate(true);
        setPrevEndDate(null);
        setTimeValid(true);
    };
    var handleTimeChange = function (_a) {
        var startDate = _a.startDate, endDate = _a.endDate;
        setStartDate(startDate);
        setEndDate(endDate);
        setPrevEndDate(endDate);
        setPredefinedDate(false);
    };
    var handleTimeClear = function () {
        setStartDate(startDate ? getStartOfDay(startDate) : null);
        setEndDate(endDate ? getEndOfDay(endDate) : null);
        setPrevEndDate(null);
        setPredefinedDate(false);
    };
    var handleSave = function () {
        var startDateMs = startDate ? startDate.getTime() : startDate;
        var endDateMs = endDate ? endDate.getTime() : endDate;
        onChange({ startDate: startDateMs, endDate: endDateMs });
        setOpen(false);
    };
    var handleCancel = function () {
        init();
        setPrevEndDate(null);
        setTimeValid(true);
        setOpen(false);
    };
    var handleClearDate = function () {
        setStartDate(null);
        setEndDate(null);
        setPrevEndDate(null);
        setPredefinedDate(false);
        onChange({ startDate: null, endDate: null });
    };
    var openDatePicker = function () { return setOpen(true); };
    var formatWeekDay = function (d) { return d.substring(0, 3); };
    var getTriggerButtonText = function () {
        if (startDate && endDate) {
            var startDateFormatted = format(startDate, DATE_FORMAT);
            var endDateFormatted = format(endDate, DATE_FORMAT);
            var startTime = format(startDate, TIME_FORMAT);
            var endTime = format(endDate, TIME_FORMAT);
            return startDateFormatted + "/" + startTime + " - " + (isSameDate(startDate, endDate) ? '' : endDateFormatted + '/') + endTime;
        }
        return 'Set an exact time';
    };
    var renderDayContent = function (dayOfMonth) {
        return React.createElement("div", null, dayOfMonth);
    };
    var clearIcon = !noClear ? (React.createElement(DatePickerControlIcon, { onClick: handleClearDate, type: "button" },
        React.createElement(Icon, { name: "times", fitted: true }))) : null;
    var openIcon = (React.createElement(DatePickerControlIcon, { onClick: openDatePicker, type: "button" },
        React.createElement(Icon, { name: "calendar-alt", fitted: true })));
    return (React.createElement(DatePickerContainer, { fluid: fluid, ref: outRef },
        React.createElement(DatePickerControlWrapper, { fluid: fluid },
            React.createElement(DatePickerControl, { isEmpty: !startDate && !endDate, onClick: openDatePicker, type: "button" }, getTriggerButtonText()),
            startDate && endDate ? clearIcon : openIcon),
        open && (React.createElement(DatePickerModal, { position: modalPosition },
            React.createElement(DatePickerCloseButton, { onClick: handleCancel },
                React.createElement(Icon, { name: "times", fitted: true })),
            React.createElement(DatePickerRow, null,
                React.createElement(DatePickerCalendar, null,
                    React.createElement(PredefinedDates, { startDate: startDate, endDate: endDate, onChange: handlePredefinedDateChange, values: predefinedDates }),
                    React.createElement(ReactDatePicker, { inline: true, selected: startDate, openToDate: endDate || currentDate, onChange: handleDateChange, startDate: startDate, endDate: endDate, selectsRange: true, locale: localeName, monthsShown: 2, renderDayContents: renderDayContent, maxDate: getMaxDate(currentDate, { startDate: startDate, endDate: endDate }, maxDaysRange), disabledKeyboardNavigation // removes highlighted day
                        : true, formatWeekDay: formatWeekDay, previousMonthButtonLabel: "", nextMonthButtonLabel: "" }))),
            React.createElement(DatePickerRow, null,
                React.createElement(TimeControl, { startDate: startDate, endDate: endDate, onChange: handleTimeChange, onChangeRaw: setTimeValid, onClear: handleTimeClear, predefinedTime: predefinedDate })),
            React.createElement(DatePickerFooter, null,
                React.createElement(Button, { secondary: true, onClick: handleCancel }, "Cancel"),
                React.createElement(DatePickerSaveButtonWrapper, null,
                    startDate && !endDate && (React.createElement(SaveButtonHelper, null, "Please, select the end of timeframe")),
                    React.createElement(Button, { disabled: !valid, onClick: handleSave }, "Save")))))));
};
var DatePickerModal = styled('div').withConfig({ displayName: "DatePickerModal", componentId: "sc-dtrdhq" })(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  min-width: 870px;\n  position: absolute;\n  top: 0;\n  background: #ffffff\n    linear-gradient(180deg, #f2f2f2 0%, #ffffff 13%, #ffffff 100%) 0 0 no-repeat;\n  box-shadow: 0 30px 80px rgba(0, 0, 0, 0.05);\n  padding: 20px 30px;\n  display: flex;\n  flex-direction: column;\n  border-radius: ", ";\n  z-index: 9999;\n  ", "\n"], ["\n  min-width: 870px;\n  position: absolute;\n  top: 0;\n  background: #ffffff\n    linear-gradient(180deg, #f2f2f2 0%, #ffffff 13%, #ffffff 100%) 0 0 no-repeat;\n  box-shadow: 0 30px 80px rgba(0, 0, 0, 0.05);\n  padding: 20px 30px;\n  display: flex;\n  flex-direction: column;\n  border-radius: ", ";\n  z-index: 9999;\n  ",
    "\n"])), DATEPICKER_BORDER_RADIUS, function (_a) {
    var position = _a.position;
    return ({
        right: position === 'left' ? 0 : 'unset',
    });
});
var DatePickerRow = styled('div').withConfig({ displayName: "DatePickerRow", componentId: "sc-13n32q" })(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  display: flex;\n  margin-bottom: 20px;\n  border-bottom: 1px solid #c7c7cb;\n"], ["\n  display: flex;\n  margin-bottom: 20px;\n  border-bottom: 1px solid #c7c7cb;\n"])));
var DatePickerContainer = styled('div').withConfig({ displayName: "DatePickerContainer", componentId: "sc-96sfc0" })(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  position: relative;\n  ", "\n"], ["\n  position: relative;\n  ",
    "\n"])), function (_a) {
    var fluid = _a.fluid;
    return ({
        width: fluid ? '100%' : 'auto',
    });
});
var DatePickerControlWrapper = styled('div').withConfig({ displayName: "DatePickerControlWrapper", componentId: "sc-16fdbin" })(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  border: 1px solid ", ";\n  border-radius: ", ";\n  height: 35px;\n\n  ", "\n"], ["\n  display: flex;\n  align-items: center;\n  border: 1px solid ", ";\n  border-radius: ", ";\n  height: 35px;\n\n  ",
    "\n"])), function (_a) {
    var theme = _a.theme;
    return theme.greyscale.dark;
}, DATEPICKER_BORDER_RADIUS, function (_a) {
    var fluid = _a.fluid;
    return ({
        width: fluid ? '100%' : '330px',
    });
});
var DatePickerControl = styled('button').withConfig({ displayName: "DatePickerControl", componentId: "sc-aseqd0" })(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  cursor: pointer;\n  background: transparent;\n  border: none;\n  outline: none;\n  font-size: 14px;\n  flex-grow: 1;\n  text-align: left;\n  white-space: nowrap;\n  height: 35px;\n  border-bottom-left-radius: ", ";\n  border-top-left-radius: ", ";\n  padding: 0 10px;\n\n  ", "\n"], ["\n  cursor: pointer;\n  background: transparent;\n  border: none;\n  outline: none;\n  font-size: 14px;\n  flex-grow: 1;\n  text-align: left;\n  white-space: nowrap;\n  height: 35px;\n  border-bottom-left-radius: ", ";\n  border-top-left-radius: ", ";\n  padding: 0 10px;\n\n  ",
    "\n"])), DATEPICKER_BORDER_RADIUS, DATEPICKER_BORDER_RADIUS, function (_a) {
    var isEmpty = _a.isEmpty;
    return isEmpty && {
        fontStyle: 'italic',
    };
});
var DatePickerControlIcon = styled('button').withConfig({ displayName: "DatePickerControlIcon", componentId: "sc-9n596n" })(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  cursor: pointer;\n  background: transparent;\n  border: none;\n  outline: none;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  flex-grow: 0;\n  height: 35px;\n  border-bottom-right-radius: ", ";\n  border-top-right-radius: ", ";\n  padding: 0 10px;\n"], ["\n  cursor: pointer;\n  background: transparent;\n  border: none;\n  outline: none;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  flex-grow: 0;\n  height: 35px;\n  border-bottom-right-radius: ", ";\n  border-top-right-radius: ", ";\n  padding: 0 10px;\n"])), DATEPICKER_BORDER_RADIUS, DATEPICKER_BORDER_RADIUS);
var DatePickerFooter = styled('footer').withConfig({ displayName: "DatePickerFooter", componentId: "sc-sutdxp" })(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n"], ["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n"])));
var DatePickerCloseButton = styled('button').withConfig({ displayName: "DatePickerCloseButton", componentId: "sc-4p7qqu" })(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  cursor: pointer;\n  position: absolute;\n  right: 5px;\n  top: 5px;\n  background: transparent;\n  border: none;\n  outline: none;\n  padding: 5px;\n"], ["\n  cursor: pointer;\n  position: absolute;\n  right: 5px;\n  top: 5px;\n  background: transparent;\n  border: none;\n  outline: none;\n  padding: 5px;\n"])));
var DatePickerSaveButtonWrapper = styled('div').withConfig({ displayName: "DatePickerSaveButtonWrapper", componentId: "sc-14paw7p" })(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n"], ["\n  display: flex;\n  align-items: center;\n"])));
var SaveButtonHelper = styled('span').withConfig({ displayName: "SaveButtonHelper", componentId: "sc-1l4r55r" })(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n  margin-right: 20px;\n  font-style: italic;\n  font-size: 12px;\n  white-space: nowrap;\n"], ["\n  margin-right: 20px;\n  font-style: italic;\n  font-size: 12px;\n  white-space: nowrap;\n"])));
var DatePickerCalendar = styled('div').withConfig({ displayName: "DatePickerCalendar", componentId: "sc-1h6m8il" })(function (_a) {
    var _b;
    var theme = _a.theme;
    return (_b = {
            display: 'flex',
            height: '390px'
        },
        _b[".react-datepicker__time-container\n  .react-datepicker__time\n  .react-datepicker__time-box\n  ul.react-datepicker__time-list\n  li.react-datepicker__time-list-item--selected,\n  .react-datepicker__time-container\n  .react-datepicker__time\n  .react-datepicker__time-box\n  ul.react-datepicker__time-list\n  li.react-datepicker__time-list-item--selected:hover"] = {
            background: theme.colors.primary.default,
        },
        _b[".react-datepicker__day--in-range.react-datepicker__day--range-start div,\n  .react-datepicker__day--in-range.react-datepicker__day--range-end div"] = {
            borderRadius: '50%',
            background: theme.colors.primary.default,
            color: theme.colors.white.default,
        },
        _b[".react-datepicker__day--selected,\n  .react-datepicker__day--selected:hover,\n  .react-datepicker__day--in-selecting-range:hover,\n  .react-datepicker__day--in-range:hover,\n  .react-datepicker__day--in-range,\n  .react-datepicker__day--in-range:hover,\n  .react-datepicker__day--in-selecting-range,\n  .react-datepicker__day--in-selecting-range:hover,\n  .react-datepicker__month-text--selected:hover,\n  .react-datepicker__month-text--in-selecting-range:hover,\n  .react-datepicker__month-text--in-range:hover,\n  .react-datepicker__quarter-text--selected:hover,\n  .react-datepicker__quarter-text--in-selecting-range:hover,\n  .react-datepicker__quarter-text--in-range:hover,\n  .react-datepicker__year-text--selected:hover,\n  .react-datepicker__year-text--in-selecting-range:hover,\n  .react-datepicker__year-text--in-range:hover"] = {
            background: theme.colors.primary.verylight,
            color: '#000000',
        },
        _b);
});
DatePickerCalendar.defaultProps = {
    theme: defaultTheme,
};
var DatePickerWrapper = styled(DatePickerComponent).withConfig({ displayName: "DatePickerWrapper", componentId: "sc-dd7foi" })(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n  position: relative;\n"], ["\n  position: relative;\n"])));
export var DatePicker = function (props) { return (React.createElement(DatePickerWrapper, __assign({}, props))); };
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11;
