var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import React from 'react';
import styled from 'styled-components';
import { endOfDay, isSameMinute, startOfDay, subDays, subMonths, subWeeks, subYears, } from 'date-fns';
import defaultTheme from "../../theme";
import { PredefinedDateLabels } from './types';
var isSameDateRange = function (dateRange, predefinedDate) {
    var initialStart = dateRange.startDate, initialEnd = dateRange.endDate;
    var startDate = predefinedDate.start, endDate = predefinedDate.end;
    if (initialStart && initialEnd) {
        return (isSameMinute(initialStart, startDate) && isSameMinute(initialEnd, endDate));
    }
    return false;
};
export var PredefinedDates = function (_a) {
    var startDate = _a.startDate, endDate = _a.endDate, onChange = _a.onChange, values = _a.values;
    var currentDate = new Date();
    var predefinedDates = [
        {
            text: PredefinedDateLabels.LAST_DAY,
            start: subDays(currentDate, 1),
            end: currentDate,
        },
        {
            text: PredefinedDateLabels.YESTARDAY,
            start: startOfDay(subDays(currentDate, 1)),
            end: endOfDay(subDays(currentDate, 1)),
        },
        {
            text: PredefinedDateLabels.LAST_WEEK,
            start: subWeeks(currentDate, 1),
            end: currentDate,
        },
        {
            text: PredefinedDateLabels.LAST_MONTH,
            start: subMonths(currentDate, 1),
            end: currentDate,
        },
        {
            text: PredefinedDateLabels.LAST_YEAR,
            start: subYears(currentDate, 1),
            end: currentDate,
        },
    ];
    var filteredPredefinedDates = values
        ? predefinedDates.filter(function (_a) {
            var text = _a.text;
            return values.indexOf(text) !== -1;
        })
        : predefinedDates;
    var handleClick = function (item) { return function () {
        var startDate = item.start, endDate = item.end;
        onChange({ startDate: startDate, endDate: endDate });
    }; };
    return (React.createElement(PredefinedDatesWrapper, null,
        React.createElement(PredefinedDatesHeader, null, "Predefined periods:"),
        React.createElement(PredefinedDatesList, null, filteredPredefinedDates.map(function (item) {
            var isSelected = isSameDateRange({ startDate: startDate, endDate: endDate }, { start: item.start, end: item.end });
            return (React.createElement(PredefinedDatesItem, { key: item.text },
                React.createElement(PredefinedDatesButton, { onClick: handleClick(item), isSelected: isSelected, type: "button" }, item.text)));
        }))));
};
export var PredefinedDatesHeader = styled('header').withConfig({ displayName: "PredefinedDatesHeader", componentId: "sc-xyupay" })(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  margin-bottom: 24px;\n  padding: 0 10px;\n  line-height: 21px;\n  font-weight: bold;\n"], ["\n  margin-bottom: 24px;\n  padding: 0 10px;\n  line-height: 21px;\n  font-weight: bold;\n"])));
export var PredefinedDatesList = styled('ul').withConfig({ displayName: "PredefinedDatesList", componentId: "sc-1pwiozs" })(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  list-style: none;\n  margin-top: 0;\n  margin-bottom: 30px;\n  padding: 0;\n"], ["\n  list-style: none;\n  margin-top: 0;\n  margin-bottom: 30px;\n  padding: 0;\n"])));
export var PredefinedDatesItem = styled('li').withConfig({ displayName: "PredefinedDatesItem", componentId: "sc-tsz3im" })(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  &:not(:last-child) {\n    margin: 15px 0;\n  }\n"], ["\n  &:not(:last-child) {\n    margin: 15px 0;\n  }\n"])));
export var PredefinedDatesButton = styled('button').withConfig({ displayName: "PredefinedDatesButton", componentId: "sc-1mdohrs" })(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  cursor: pointer;\n  border: none;\n  outline: none;\n  font-size: 14px;\n  padding: 6px 10px;\n  background: transparent;\n  text-align: left;\n\n  border-radius: ", ";\n\n  &:hover,\n  &:focus {\n    color: ", ";\n  }\n\n  ", "\n"], ["\n  cursor: pointer;\n  border: none;\n  outline: none;\n  font-size: 14px;\n  padding: 6px 10px;\n  background: transparent;\n  text-align: left;\n\n  border-radius: ", ";\n\n  &:hover,\n  &:focus {\n    color: ", ";\n  }\n\n  ",
    "\n"])), function (_a) {
    var theme = _a.theme;
    return theme.sizes.borderRadiusInput;
}, function (_a) {
    var theme = _a.theme;
    return theme.greyscale.darker;
}, function (_a) {
    var isSelected = _a.isSelected, theme = _a.theme;
    return isSelected && {
        color: theme.colors.white.default,
        background: theme.colors.primary.default,
        '&:hover, &:focus': {
            background: theme.colors.primary.hover,
            color: theme.colors.white.default,
        },
    };
});
PredefinedDatesButton.defaultProps = {
    theme: defaultTheme,
};
var PredefinedDatesWrapper = styled('div').withConfig({ displayName: "PredefinedDatesWrapper", componentId: "sc-avwcf0" })(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  margin-top: 59px;\n  margin-right: 20px;\n  padding-right: 20px;\n  border-right: 1px solid #c7c7cb;\n  font-weight: normal;\n  font-size: 14px;\n  line-height: 21px;\n  color: #161616;\n"], ["\n  margin-top: 59px;\n  margin-right: 20px;\n  padding-right: 20px;\n  border-right: 1px solid #c7c7cb;\n  font-weight: normal;\n  font-size: 14px;\n  line-height: 21px;\n  color: #161616;\n"])));
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
