import { compareDesc, endOfDay, startOfDay, isSameDay, isSameMonth, isSameYear, parse, addDays, } from 'date-fns';
import { TIME_FORMAT, TIME_REGEXP } from './consts';
export var isSameDate = function (start, end) {
    return isSameDay(start, end) && isSameMonth(start, end) && isSameYear(start, end);
};
export var getStartOfDay = function (controlDate) {
    var date = controlDate || new Date();
    return startOfDay(date);
};
export var getEndOfDay = function (controlDate) {
    var date = controlDate || new Date();
    return endOfDay(date);
};
export var isValidDateRange = function (start, end) {
    if (!start && !end) {
        return true;
    }
    return start && end && compareDesc(start, end) !== -1; // 'start date' is before 'end date' or the same
};
export var getDateFromTimeStr = function (timeStr, baseDate) {
    var match = timeStr.match(TIME_REGEXP);
    if (match) {
        /* 12h format:
        const hours = match[2];
        const minutes = match[4] || '00';
        const timeOfDay = match[5].toLowerCase();
        const fullTime = `${hours}:${minutes} ${timeOfDay}`;
        */
        var hours = match[1];
        var minutes = match[2];
        var seconds = match[4] || '00';
        var fullTime = hours + ":" + minutes + ":" + seconds;
        return parse(fullTime, TIME_FORMAT, baseDate);
    }
    return baseDate;
};
export var getMaxDate = function (currentDate, date, maxDaysRange) {
    var startDate = date.startDate, endDate = date.endDate;
    if (maxDaysRange && startDate && !endDate) {
        var lastAvailableDate = addDays(startDate, maxDaysRange);
        if (lastAvailableDate < currentDate) {
            return lastAvailableDate;
        }
    }
    return currentDate;
};
