var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useEffect, useImperativeHandle, useRef, useState } from 'react';
import styled from 'styled-components';
import { borderRadius } from "../../utils";
import { border, fluid, inputStyles } from './helpers';
var IE_HEIGHT_TOLERANCE = 0.1;
export var StyledTextarea = styled.textarea.withConfig({ displayName: "StyledTextarea", componentId: "sc-u0w57q" })(function (_a) {
    var resize = _a.resize;
    return ({ resize: resize || 'none' });
}, inputStyles, function (_a) {
    var plain = _a.plain, rest = __rest(_a, ["plain"]);
    return plain ? { border: 0 } : __assign(__assign({}, border(rest)), borderRadius(rest));
}, { height: 'auto' }, fluid, function (_a) {
    var fitted = _a.fitted;
    return (fitted ? { height: '100%' } : null);
}, function (_a) {
    var theme = _a.theme;
    return ({
        boxShadow: "0 0 0 1px " + theme.greyscale.medium,
        borderWidth: 6,
        padding: '0px 6px',
        borderColor: 'transparent',
        '&:focus, &:hover, &:focus:hover': {
            boxShadow: "0 0 0 1px " + theme.greyscale.dark,
            borderWidth: 6,
            borderColor: 'transparent',
        },
    });
});
export var Textarea = React.forwardRef(function (_a, ref) {
    var _b = _a.minRows, minRows = _b === void 0 ? 1 : _b, _c = _a.maxRows, maxRows = _c === void 0 ? 10 : _c, value = _a.value, onChange = _a.onChange, rest = __rest(_a, ["minRows", "maxRows", "value", "onChange"]);
    var _d = useState(0), baseHeight = _d[0], setBaseHeight = _d[1];
    var textareaRef = useRef(null);
    var rowHeightRef = useRef(1);
    useImperativeHandle(ref, function () { return ({
        focus: function () {
            if (textareaRef.current) {
                textareaRef.current.focus();
            }
        },
    }); });
    var calculateRow = function (node, baseHeightValue) {
        node.rows = minRows;
        node.style.overflow = 'hidden';
        var offset = (node.scrollHeight - baseHeightValue) / rowHeightRef.current;
        var rows = minRows + (offset > IE_HEIGHT_TOLERANCE ? Math.ceil(offset) : 0);
        node.rows = Math.min(rows, maxRows);
        if (rows > maxRows) {
            node.style.overflow = 'auto';
        }
    };
    useEffect(function () {
        var node = textareaRef.current;
        if (node) {
            var _a = getComputedStyle(node), lineHeight = _a.lineHeight, fontSize = _a.fontSize, paddingTop = _a.paddingTop, paddingBottom = _a.paddingBottom;
            var rowHeight = parseFloat(lineHeight);
            if (Number.isNaN(rowHeight)) {
                rowHeight = parseFloat(fontSize);
            }
            var baseHeightValue = parseFloat(paddingTop) +
                parseFloat(paddingBottom) +
                rowHeight * minRows;
            rowHeightRef.current = rowHeight;
            calculateRow(node, baseHeightValue);
            setBaseHeight(baseHeightValue);
        }
    }, [calculateRow, minRows]);
    var onChangeHandler = function (event) {
        var node = textareaRef.current;
        if (node) {
            calculateRow(node, baseHeight);
            if (onChange) {
                onChange(event);
            }
        }
    };
    return (React.createElement(StyledTextarea, __assign({}, rest, { value: value, ref: textareaRef, onChange: onChangeHandler, rows: minRows })));
});
